@@ -5,6 +5,7 @@
 # Turns all annotations into string literals.
 # This is one exception to the external import rule.
 from __future__ import annotations
+from typing import Union
 import requests
 import time
 import urllib3
@@ -89,9 +90,9 @@ class BIG:
         # Connect to device
         self._connect()
 
-    def load(self, path: str) -> list[RESTObject]:
+    def load(self, path: str) -> Union[list[RESTObject], RESTObject]:
         """
-        Loads a list of objects from the device.
+        Loads one object or a list of objects from the device.
 
         Sends an HTTP GET request to the iControl REST API.
 
@@ -109,13 +110,13 @@ class BIG:
         if response.status_code != 200:
             raise RESTAPIError(response, self.debug)
         response_json = response.json()
-        objects = []
         if "items" in response_json:
+            collection = []
             for obj in response_json["items"]:
-                objects.append(RESTObject(obj))
+                collection.append(RESTObject(obj))
+            return collection
         else:
-            objects.append(RESTObject(response_json))
-        return objects
+            return RESTObject(response_json)
 
     def save(self, obj: RESTObject) -> RESTObject:
         """
