@@ -1,6 +1,6 @@
 """File with version and history information."""
 
-__version__ = '1.0.2'
+__version__ = '1.0.4'
 
 """
 History Information:
@@ -10,4 +10,8 @@ History Information:
     Removed tests folder from pip
 1.0.2
     Fixed documentation
+1.0.3
+    Fixed documentation
+1.0.4
+    Fixed issue #4
 """
